<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2011 Claus Due <claus@wildside.dk>, Wildside A/S
*
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 3 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

require_once t3lib_extMgm::extPath('cms', 'layout/class.tx_cms_layout.php');
require_once t3lib_extMgm::extPath('cms', 'layout/interfaces/interface.tx_cms_layout_tt_content_drawitemhook.php');

/**
 * Fluid Template preview renderer
 *
 * @package Flux
 * @subpackage Backend
 */
class Tx_Flux_Backend_Preview implements tx_cms_layout_tt_content_drawItemHook {

	/**
	 * @var Tx_Extbase_Object_ObjectManager
	 */
	protected $objectManager;

	/**
	 * @var Tx_Fluid_View_StandaloneView
	 */
	protected $view;

	/**
	 * @var Tx_Flux_Configuration_ConfigurationManager
	 */
	protected $configurationManager;

	/**
	 * @var Tx_Flux_Service_Json
	 */
	protected $jsonService;

	/**
	 * @var Tx_Flux_Service_FlexForm
	 */
	protected $flexform;

	/**
	 * CONSTRUCTOR
	 */
	public function __construct() {
		$this->objectManager = t3lib_div::makeInstance('Tx_Extbase_Object_ObjectManager');
		$this->jsonService = $this->objectManager->get('Tx_Flux_Service_Json');
		$this->configurationManager = $this->objectManager->get('Tx_Flux_Configuration_ConfigurationManager');
		$this->flexform = $this->objectManager->get('Tx_Flux_Service_FlexForm');
		$this->view = $this->objectManager->get('Tx_Fluid_View_StandaloneView');
	}

	/**
	 *
	 * @param tx_cms_layout $parentObject
	 * @param boolean $drawItem
	 * @param string $headerContent
	 * @param string $itemContent
	 * @param array $row
	 */
	public function preProcess(tx_cms_layout &$parentObject, &$drawItem, &$headerContent, &$itemContent, array &$row) {
		$flexFormConfiguration = Tx_Flux_Core::getRegisteredFlexForms('contentObject', $row['CType']);
		if (!$flexFormConfiguration && !empty($row['list_type'])) {
			$flexFormConfiguration = Tx_Flux_Core::getRegisteredFlexForms('plugin', $row['list_type']);
		}
		if ($flexFormConfiguration) {
			$templatePathAndFilename = $flexFormConfiguration['templateFilename'];
			$templatePathAndFilename = t3lib_div::getFileAbsFileName($templatePathAndFilename);
			if (file_exists($templatePathAndFilename)) {
				$typoScript = $this->configurationManager->getConfiguration(Tx_Extbase_Configuration_ConfigurationManagerInterface::CONFIGURATION_TYPE_FULL_TYPOSCRIPT);
				$extension = str_replace('_', '', $flexFormConfiguration['extensionName']);
				$settings = $typoScript['plugin.']['tx_' . $extension . '.']['view.'];
				$paths = Tx_Extbase_Utility_TypoScript::convertTypoScriptArrayToPlainArray($settings);
				try {
					$this->flexform->setContentObjectData($row);
					$flexform = $this->flexform->getAll();
					$view = $this->objectManager->get('Tx_Flux_MVC_View_ExposedStandaloneView');
					$view->setTemplatePathAndFilename($templatePathAndFilename);
					$view->assignMultiple($flexform);
					$view->assignMultiple((array) $variables);
					$stored = $view->getStoredVariable('Tx_Flux_ViewHelpers_FlexformViewHelper', 'storage', 'Configuration');
					$variables = array_merge($stored, $flexFormConfiguration['variables'], $this->flexform->getAllAndTransform($stored['fields']));
					$variables['label'] = $stored['label'];
					$variables['config'] = $stored;
					$variables['row'] = $row;
					$view->setPartialRootPath(t3lib_div::getFileAbsFileName($paths['partialRootPath']));
					$view->setLayoutRootPath(t3lib_div::getFileAbsFileName($paths['layoutRootPath']));
					$view->setTemplatePathAndFilename($templatePathAndFilename);
					$view->assignMultiple($variables);
					$itemContent = $view->renderStandaloneSection('Preview', $variables);
					$headerContent = '<strong>' . $stored['label'] . '</strong> <i>' . $row['header'] . '</i> ';
					$drawItem = FALSE;
				} catch (Exception $e) {
					$itemContent = 'INVALID: ';
					$itemContent .= basename($fceTemplateFile);
					$itemContent .= '<br />' . LF;
					$itemContent .= 'Error: ' . $e->getMessage();
				}
			}
		}
	}

	/**
	 * Preprocessing
	 *
	 * @param tx_cms_layout $parentObject
	 * @param boolean $drawItem
	 * @param type $headerContent
	 * @param type $itemContent
	 * @param array $row
	 */
	public function drawPreview(tx_cms_layout &$parentObject, &$drawItem, &$headerContent, &$itemContent, array &$row) {
	}

}
?>